====================
AsyncTeleBot
====================


.. meta::
   :description: Asynchronous pyTelegramBotAPI
   :keywords: ptba, pytba, pyTelegramBotAPI, asynctelebot, documentation


AsyncTeleBot methods
--------------------

.. automodule:: telebot.async_telebot
   :members:
   :undoc-members:
   :show-inheritance:



Asyncio filters
---------------

.. automodule:: telebot.asyncio_filters
   :members:
   :undoc-members:
   :show-inheritance:

Asyncio handler backends
------------------------



.. automodule:: telebot.asyncio_handler_backends
   :members:
   :undoc-members:
   :show-inheritance:


Extensions
------------------------



.. automodule:: telebot.ext.aio.webhooks
   :members:
   :undoc-members:
   :show-inheritance:
